@@ -24,8 +24,8 @@ require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
 
 use vars qw(@ISA $VERSION);
-@ISA = qw( ExtUtils::MM_Any ExtUtils::MM_unix );
-$VERSION = 1.01_01;
+@ISA = qw( ExtUtils::MM_Any ExtUtils::MM_Unix );
+$VERSION = 1.02_01;
 
 
 =item perl_archive
